#ifdef GL_ES
precision mediump float;
#endif

uniform sampler2D   LightTex;
uniform sampler2D   FogTex;
//1 船坞海水混合,0船坞混合
uniform int typeEnable;
 
varying vec3        diffuse;
varying vec3        ambient;
varying vec3        fog_color;
//0=白天,其它晚上
varying float       pass_index;
varying float       fog_strength;

varying vec3        nightLightColor;



#ifdef GL_ES
 varying lowp vec4      v_fragmentColor; 
 varying mediump vec2   v_texCoord; 
#else
 varying vec4 v_fragmentColor;
 varying vec2 v_texCoord; 
#endif 



vec3 mb = vec3(0.5,0.5,0.5);

//叠加
float blendOverlayf(float base,float blend) {
    return base < 0.5 ? (2.0 * base * blend) : (1.0 - 2.0 * (1.0 - base) * (1.0 - blend));
}

/*
    混合
    @param base 底图
    @param blend 混合图
    @param alpha 混合值
*/
vec3 mmix(vec3 base,vec3 blend,float alpha ) {
    float r         = blendOverlayf(base.r, blend.r);
    float g         = blendOverlayf(base.g, blend.g);
    float b         = blendOverlayf(base.b, blend.b);

    vec3 overlay    = vec3(r, g, b);

    return mix(base, overlay, alpha);    
}

float getPassIndex(vec4 pass,float passType) {
    // g:白天
    // b:晚上
    return passType == 0.0 ? pass.g : pass.b;
}

void main(void) {
    vec4 baseSrc            = texture2D( CC_Texture0, v_texCoord );  

    // vec2 coord              = typeEnable == 1 ? vec2(v_texCoord.x,v_texCoord.y) : v_texCoord;
    vec2 coord = v_texCoord;
    
    //混合图
    vec4 blendSrc           = texture2D( LightTex, coord );  
    //雾
    vec4 fogSrc             = texture2D( FogTex, v_texCoord );  

    vec3 dst3;   
    
    float blendPass         = getPassIndex(blendSrc,pass_index);
    //如果是夜晚,则0-251为光照，252以上是灯光的颜色
    float nightThreshold    = pass_index != 0.0 ? (blendPass > 0.985 ? blendPass : 0.0) : 0.0;

   blendPass                = pass_index != 0.0 ? (blendPass <= 0.985 ? blendPass / 0.96 : blendPass) : blendPass;


    
    vec3 mid                = mix(mb,diffuse,blendPass);

    // 受光面
    // vec3 mid                = diffuse * blendPass;
    dst3                    = mmix(baseSrc.rgb,mid,blendPass);
    // 背光面
    mid                     =  mix(mb,ambient,1.0 - blendPass);//ambient * (1.0 - blendPass);     
    dst3                    = mmix(dst3,mid,1.0 - blendPass);
    dst3                    = nightThreshold > 0.0 ? nightLightColor * nightThreshold : dst3;

    dst3                    = mix(dst3, fog_color , fogSrc.r * fog_strength);

    


    gl_FragColor                = typeEnable == 1 ? vec4(dst3,baseSrc.a) : vec4(dst3,blendSrc.r);
    

}
