#ifdef GL_ES
precision mediump float;
#endif

uniform vec4  TexSize;

#ifdef GL_ES
 varying lowp vec4      v_fragmentColor; 
 varying mediump vec2   v_texCoord; 
#else
 varying vec4 v_fragmentColor;
 varying vec2 v_texCoord; 
#endif 


vec4 dip_filter(mat3 _filter, sampler2D _image, vec2 _xy, vec2 texSize)
{
	mat3 _filter_pos_delta_x=mat3(vec3(-1.0, 0.0, 1.0), vec3(0.0, 0.0 ,1.0) ,vec3(1.0,0.0,1.0));
	mat3 _filter_pos_delta_y=mat3(vec3(-1.0,-1.0,-1.0),vec3(-1.0,0.0,0.0),vec3(-1.0,1.0,1.0));
	vec4 final_color = vec4(0.0, 0.0, 0.0, 0.0);
	for(int i = 0; i<3; i++)
	{
		for(int j = 0; j<3; j++)
		{
			vec2 _xy_new = vec2(_xy.x + _filter_pos_delta_x[i][j], _xy.y + _filter_pos_delta_y[i][j]); 
			vec2 _uv_new = vec2(_xy_new.x/texSize.x, _xy_new.y/texSize.y);
			final_color += texture2D(_image,_uv_new) * _filter[i][j];
		}
	}
	return final_color;
}


void main1(void) {
    vec2 intXY = vec2(v_texCoord.x * TexSize.x, v_texCoord.y * TexSize.y);  
	mat3 _smooth_fil_b = mat3(1.0/9.0,1.0/9.0,1.0/9.0,
	 						1.0/9.0,1.0/9.0,1.0/9.0,
	 						1.0/9.0,1.0/9.0,1.0/9.0);
	mat3 _smooth_fil = mat3(0.4/9.0,0.4/9.0,0.4/9.0,
	 						0.4/9.0,0.4/9.0,0.4/9.0,
	 						0.4/9.0,0.4/9.0,0.4/9.0);
    vec4 tmp = dip_filter(_smooth_fil, CC_Texture0, intXY, TexSize);
	gl_FragColor = tmp; 
}

void main(void) {
    //this will be our RGBA sum
    vec4 sum = vec4(0.0);
    
    //our original texcoord for this fragment
    vec2 tc = v_texCoord;
    float resolution = 1280.0;
    float radius = 1.0;
    vec2 dir = vec2(1.0,1.0);
    
    //the amount to blur, i.e. how far off center to sample from 
    //1.0 -> blur by one pixel
    //2.0 -> blur by two pixels, etc.
    float blur = radius/720.0; 
    
    //the direction of our blur
    //(1.0, 0.0) -> x-axis blur
    //(0.0, 1.0) -> y-axis blur
    float hstep = dir.x;
    float vstep = dir.y;
    
    
    //apply blurring, using a 9-tap filter with predefined gaussian weights
    
    sum += texture2D(CC_Texture0, vec2(tc.x - 4.0*blur*hstep, tc.y - 4.0*blur*vstep)) * 0.0162162162;
    sum += texture2D(CC_Texture0, vec2(tc.x - 3.0*blur*hstep, tc.y - 3.0*blur*vstep)) * 0.0540540541;
    sum += texture2D(CC_Texture0, vec2(tc.x - 2.0*blur*hstep, tc.y - 2.0*blur*vstep)) * 0.1216216216;
    sum += texture2D(CC_Texture0, vec2(tc.x - 1.0*blur*hstep, tc.y - 1.0*blur*vstep)) * 0.1945945946;
    
    sum += texture2D(CC_Texture0, vec2(tc.x, tc.y)) * 0.2270270270;
    
    sum += texture2D(CC_Texture0, vec2(tc.x + 1.0*blur*hstep, tc.y + 1.0*blur*vstep)) * 0.1945945946;
    sum += texture2D(CC_Texture0, vec2(tc.x + 2.0*blur*hstep, tc.y + 2.0*blur*vstep)) * 0.1216216216;
    sum += texture2D(CC_Texture0, vec2(tc.x + 3.0*blur*hstep, tc.y + 3.0*blur*vstep)) * 0.0540540541;
    sum += texture2D(CC_Texture0, vec2(tc.x + 4.0*blur*hstep, tc.y + 4.0*blur*vstep)) * 0.0162162162;



    //discard alpha for our simple demo, multiply by vertex color and return
    gl_FragColor = vec4(sum.rgb, 1.0);
}
